splinter_open_or_create

Function splinter_open_or_create 

pub unsafe extern "C" fn splinter_open_or_create(
    name_or_path: *const c_char,
    slots: usize,
    max_value_sz: usize,
) -> c_int
@brief Opens an existing splinter store, or creates it if it does not exist. @param name_or_path The name of the shared memory object or path to the file. @param slots The total number of key-value slots if creating. @param max_value_sz The maximum value size in bytes if creating. @return 0 on success, -1 on failure.