pub unsafe extern "C" fn splinter_pulse_watchers(
slot: *mut splinter_slot,
)Expand description
@brief Internal helper to pulse the Signal Arena for a slot. @param slot pointer to a splinter_slot structure
pub unsafe extern "C" fn splinter_pulse_watchers(
slot: *mut splinter_slot,
)@brief Internal helper to pulse the Signal Arena for a slot. @param slot pointer to a splinter_slot structure