splinter_purge

Function splinter_purge 

pub unsafe extern "C" fn splinter_purge()
@brief Check each key, and zero out memory past the value length to the allocated slot length (essentially sweep out any old data). Designed to be used as part of backfill runs when I/O slamming has stopped.