splinter_slot_snapshot_t

Type Alias splinter_slot_snapshot_t 

pub type splinter_slot_snapshot_t = splinter_slot_snapshot;
@structure splinter_slot_snapshot @brief A structure to hold a snapshot of a single slot

Aliased Type

#[repr(C)]
pub struct splinter_slot_snapshot_t { pub hash: u64, pub epoch: u64, pub val_off: u32, pub val_len: u32, pub type_flag: u8, pub user_flag: u8, pub ctime: u64, pub atime: u64, pub bloom: u64, pub key: [i8; 64], }

Fields

hash: u64

@brief The FNV-1a hash of the key. 0 indicates an empty slot.

epoch: u64

@brief Per-slot epoch, incremented on write to this slot. Used for polling.

val_off: u32

@brief Offset into the VALUES region where the value data is stored.

val_len: u32

@brief The actual length of the stored value data (atomic).

type_flag: u8

@brief The slot type flags

user_flag: u8

@brief The slot user flags

ctime: u64

@brief Storage for creation time

atime: u64

@brief Storage for access time

bloom: u64

@brief Bloom bits

key: [i8; 64]

@brief The null-terminated key string.