pub unsafe extern "C" fn splinter_bump_slot(
key: *const c_char,
) -> c_intExpand description
@brief Advance the epoch of a slot without otherwise doing work Useful in conjunction with labeling for automation to fire. @param key Current key name associated with the slot.